import * as pulumi from "@pulumi/pulumi";
/**
 * Provides a Wavefront Cloud Integration for Google Cloud Billing. This allows GCP Billing cloud integrations to be created,
 * updated, and deleted.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as wavefront from "@pulumi/wavefront";
 *
 * const gcpBilling = new wavefront.CloudIntegrationGcpBilling("gcp_billing", {
 *     name: "Test Integration",
 *     projectId: "example-gcp-project",
 *     apiKey: "example-api-key",
 *     jsonKey: "{...your gcp key ...}\n",
 * });
 * ```
 *
 * ## Import
 *
 * GCP Billing Cloud Integrations can be imported by using the `id`, e.g.:
 *
 * ```sh
 * $ pulumi import wavefront:index/cloudIntegrationGcpBilling:CloudIntegrationGcpBilling gcp_billing a411c16b-3cf7-4f03-bf11-8ca05aab898d
 * ```
 */
export declare class CloudIntegrationGcpBilling extends pulumi.CustomResource {
    /**
     * Get an existing CloudIntegrationGcpBilling resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: CloudIntegrationGcpBillingState, opts?: pulumi.CustomResourceOptions): CloudIntegrationGcpBilling;
    /**
     * Returns true if the given object is an instance of CloudIntegrationGcpBilling.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is CloudIntegrationGcpBilling;
    /**
     * A list of point tag key-values to add to every point ingested using this integration.
     */
    readonly additionalTags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * API key for Google Cloud Platform (GCP).
     */
    readonly apiKey: pulumi.Output<string>;
    /**
     * Forces this resource to save, even if errors are present.
     */
    readonly forceSave: pulumi.Output<boolean | undefined>;
    /**
     * Private key for a Google Cloud Platform (GCP) service account within your project.
     * The account must have at least Viewer permissions. This key must be in the JSON format generated by GCP.
     */
    readonly jsonKey: pulumi.Output<string>;
    /**
     * The human-readable name of this integration.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The Google Cloud Platform (GCP) Project ID.
     */
    readonly projectId: pulumi.Output<string>;
    /**
     * A value denoting which cloud service this service integrates with.
     */
    readonly service: pulumi.Output<string>;
    /**
     * How often, in minutes, to refresh the service.
     */
    readonly serviceRefreshRateInMinutes: pulumi.Output<number | undefined>;
    /**
     * Create a CloudIntegrationGcpBilling resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: CloudIntegrationGcpBillingArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering CloudIntegrationGcpBilling resources.
 */
export interface CloudIntegrationGcpBillingState {
    /**
     * A list of point tag key-values to add to every point ingested using this integration.
     */
    additionalTags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * API key for Google Cloud Platform (GCP).
     */
    apiKey?: pulumi.Input<string>;
    /**
     * Forces this resource to save, even if errors are present.
     */
    forceSave?: pulumi.Input<boolean>;
    /**
     * Private key for a Google Cloud Platform (GCP) service account within your project.
     * The account must have at least Viewer permissions. This key must be in the JSON format generated by GCP.
     */
    jsonKey?: pulumi.Input<string>;
    /**
     * The human-readable name of this integration.
     */
    name?: pulumi.Input<string>;
    /**
     * The Google Cloud Platform (GCP) Project ID.
     */
    projectId?: pulumi.Input<string>;
    /**
     * A value denoting which cloud service this service integrates with.
     */
    service?: pulumi.Input<string>;
    /**
     * How often, in minutes, to refresh the service.
     */
    serviceRefreshRateInMinutes?: pulumi.Input<number>;
}
/**
 * The set of arguments for constructing a CloudIntegrationGcpBilling resource.
 */
export interface CloudIntegrationGcpBillingArgs {
    /**
     * A list of point tag key-values to add to every point ingested using this integration.
     */
    additionalTags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * API key for Google Cloud Platform (GCP).
     */
    apiKey: pulumi.Input<string>;
    /**
     * Forces this resource to save, even if errors are present.
     */
    forceSave?: pulumi.Input<boolean>;
    /**
     * Private key for a Google Cloud Platform (GCP) service account within your project.
     * The account must have at least Viewer permissions. This key must be in the JSON format generated by GCP.
     */
    jsonKey: pulumi.Input<string>;
    /**
     * The human-readable name of this integration.
     */
    name?: pulumi.Input<string>;
    /**
     * The Google Cloud Platform (GCP) Project ID.
     */
    projectId: pulumi.Input<string>;
    /**
     * A value denoting which cloud service this service integrates with.
     */
    service: pulumi.Input<string>;
    /**
     * How often, in minutes, to refresh the service.
     */
    serviceRefreshRateInMinutes?: pulumi.Input<number>;
}
